[−][src]Struct alacritty::input::Processor
Processes input from glutin.
An escape sequence may be emitted in case specific keys or key combinations are activated.
Fields
ctx: Ahighlighted_url: &'a Option<Url>_phantom: PhantomData<T>Implementations
impl<'a, T: EventListener, A: ActionContext<T>> Processor<'a, T, A>[src]
pub fn new(ctx: A, highlighted_url: &'a Option<Url>) -> Self[src]
pub fn mouse_moved(&mut self, position: PhysicalPosition<f64>)[src]
fn get_mouse_side(&self) -> Side[src]
fn normal_mouse_report(&mut self, button: u8)[src]
fn sgr_mouse_report(&mut self, button: u8, state: ElementState)[src]
fn mouse_report(&mut self, button: u8, state: ElementState)[src]
fn on_mouse_press(&mut self, button: MouseButton)[src]
fn on_right_click(&mut self, point: Point)[src]
Handle selection expansion on right click.
fn expand_selection(&mut self, point: Point, selection_type: SelectionType)[src]
Expand existing selection.
fn on_left_click(&mut self, point: Point)[src]
Handle left click selection and vi mode cursor movement.
fn on_mouse_release(&mut self, button: MouseButton)[src]
pub fn mouse_wheel_input(&mut self, delta: MouseScrollDelta, phase: TouchPhase)[src]
fn scroll_terminal(&mut self, new_scroll_px: f64)[src]
pub fn on_focus_change(&mut self, is_focused: bool)[src]
pub fn mouse_input(&mut self, state: ElementState, button: MouseButton)[src]
pub fn key_input(&mut self, input: KeyboardInput)[src]
Process key input.
pub fn modifiers_input(&mut self, modifiers: ModifiersState)[src]
Modifier state change.
pub fn reset_mouse_cursor(&mut self)[src]
Reset mouse cursor based on modifier and terminal state.
pub fn received_char(&mut self, c: char)[src]
Process a received character.
fn process_key_bindings(&mut self, input: KeyboardInput)[src]
Attempt to find a binding and execute its action.
The provided mode, mods, and key must match what is allowed by a binding for its action to be executed.
fn process_mouse_bindings(&mut self, button: MouseButton)[src]
Attempt to find a binding and execute its action.
The provided mode, mods, and key must match what is allowed by a binding for its action to be executed.
fn message_bar_mouse_state(&self) -> Option<MouseState>[src]
Check mouse state in relation to the message bar.
fn copy_selection(&mut self)[src]
Copy text selection.
fn update_url_state(&mut self, mouse_state: &MouseState)[src]
Trigger redraw when URL highlight changed.
fn mouse_state(&mut self) -> MouseState[src]
Location of the mouse cursor.
fn update_selection_scrolling(&mut self, mouse_y: i32)[src]
Handle automatic scrolling when selecting above/below the window.